==> forestry_1.12.2-5.7.0.212-sources.jar: forestry/arboriculture/items/ItemBlockDecorativeLeaves.java <==
package forestry.arboriculture.items;

import forestry.api.arboriculture.IFruitProvider;
import forestry.api.arboriculture.ITreeGenome;
import forestry.arboriculture.blocks.BlockDecorativeLeaves;
import forestry.arboriculture.genetics.TreeDefinition;
import forestry.core.items.IColoredItem;
import forestry.core.items.ItemBlockForestry;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

public class ItemBlockDecorativeLeaves extends ItemBlockForestry<BlockDecorativeLeaves> implements IColoredItem {
	public ItemBlockDecorativeLeaves(BlockDecorativeLeaves block) {
		super(block);
	}

	@Override
	public String func_77653_i(ItemStack itemStack) {
		int meta = itemStack.func_77960_j();
		BlockDecorativeLeaves block = func_179223_d();
		TreeDefinition treeDefinition = block.getTreeType(meta);
		String unlocalizedSpeciesName = treeDefinition.getUnlocalizedName();
		return ItemBlockLeaves.getDisplayName(unlocalizedSpeciesName);
	}

	@Override
	@SideOnly(Side.CLIENT)
	public int getColorFromItemstack(ItemStack itemStack, int renderPass) {
		int meta = itemStack.func_77960_j();
		BlockDecorativeLeaves block = func_179223_d();
		TreeDefinition treeDefinition = block.getTreeType(meta);

		ITreeGenome genome = treeDefinition.getGenome();

		if (renderPass == 0) {
			return genome.getPrimary().getLeafSpriteProvider().getColor(false);
		} else {
			IFruitProvider fruitProvider = genome.getFruitProvider();
			return fruitProvider.getDecorativeColor();
		}
	}
}

==> forestry_1.12.2-5.8.0.246-sources.jar: forestry/arboriculture/items/ItemBlockDecorativeLeaves.java <==
package forestry.arboriculture.items;

import net.minecraft.item.ItemStack;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.arboriculture.IFruitProvider;
import forestry.api.arboriculture.ITreeGenome;
import forestry.arboriculture.blocks.BlockAbstractLeaves;
import forestry.arboriculture.blocks.BlockDecorativeLeaves;
import forestry.arboriculture.genetics.TreeDefinition;
import forestry.core.items.IColoredItem;
import forestry.core.items.ItemBlockForestry;

public class ItemBlockDecorativeLeaves extends ItemBlockForestry<BlockDecorativeLeaves> implements IColoredItem {
	public ItemBlockDecorativeLeaves(BlockDecorativeLeaves block) {
		super(block);
	}

	@Override
	public String func_77653_i(ItemStack itemStack) {
		int meta = itemStack.func_77960_j();
		BlockDecorativeLeaves block = func_179223_d();
		TreeDefinition treeDefinition = block.getTreeType(meta);
		String unlocalizedSpeciesName = treeDefinition.getUnlocalizedName();
		return ItemBlockLeaves.getDisplayName(unlocalizedSpeciesName);
	}

	@Override
	@SideOnly(Side.CLIENT)
	public int getColorFromItemstack(ItemStack itemStack, int renderPass) {
		int meta = itemStack.func_77960_j();
		BlockDecorativeLeaves block = func_179223_d();
		TreeDefinition treeDefinition = block.getTreeType(meta);

		ITreeGenome genome = treeDefinition.getGenome();

		if (renderPass == BlockAbstractLeaves.FOLIAGE_COLOR_INDEX) {
			return genome.getPrimary().getLeafSpriteProvider().getColor(false);
		} else {
			IFruitProvider fruitProvider = genome.getFruitProvider();
			return fruitProvider.getDecorativeColor();
		}
	}
}
